==> aria2_1.4.1.orig.tar.gz: aria2-1.4.1/src/CheckIntegrityDispatcherCommand.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2009 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "CheckIntegrityDispatcherCommand.h"
#include "CheckIntegrityEntry.h"
#include "CheckIntegrityCommand.h"
#include "message.h"
#include "Logger.h"

namespace aria2 {

CheckIntegrityDispatcherCommand::CheckIntegrityDispatcherCommand
(int32_t cuid,
 const SharedHandle<CheckIntegrityMan>& fileAllocMan,
 DownloadEngine* e):SequentialDispatcherCommand<CheckIntegrityEntry>
		    (cuid, fileAllocMan, e)
{
  setStatusRealtime();
}

Command* CheckIntegrityDispatcherCommand::createCommand
(const SharedHandle<CheckIntegrityEntry>& entry)
{
  int32_t newCUID = _e->newCUID();
  logger->info("CUID#%d - Dispatching CheckIntegrityCommand CUID#%d.",
	       cuid, newCUID);
  return new CheckIntegrityCommand
    (newCUID, entry->getRequestGroup(), _e, entry);
}

} // namespace aria2

==> aria2-1.9.2.tar.gz: aria2-1.9.2/src/CheckIntegrityDispatcherCommand.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2009 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "CheckIntegrityDispatcherCommand.h"
#include "CheckIntegrityEntry.h"
#include "CheckIntegrityCommand.h"
#include "message.h"
#include "Logger.h"
#include "FileEntry.h"
#include "util.h"

namespace aria2 {

CheckIntegrityDispatcherCommand::CheckIntegrityDispatcherCommand
(cuid_t cuid,
 const SharedHandle<CheckIntegrityMan>& fileAllocMan,
 DownloadEngine* e):SequentialDispatcherCommand<CheckIntegrityEntry>
                    (cuid, fileAllocMan, e)
{
  setStatusRealtime();
}

Command* CheckIntegrityDispatcherCommand::createCommand
(const SharedHandle<CheckIntegrityEntry>& entry)
{
  cuid_t newCUID = _e->newCUID();
  if(logger->info()) {
    logger->info("CUID#%s - Dispatching CheckIntegrityCommand CUID#%s.",
                 util::itos(cuid).c_str(), util::itos(newCUID).c_str());
  }
  return new CheckIntegrityCommand
    (newCUID, entry->getRequestGroup(), _e, entry);
}

} // namespace aria2
